@@ -6,7 +6,7 @@ calculating on images.
 
 import math
 import os
-from typing import Dict, List
+from typing import Dict, List, Tuple
 
 import numpy
 from osgeo import gdal
@@ -1852,3 +1852,158 @@ def count_imgs_int_val_occur(
     applier.apply(
         _applyCalcPxlValCount, infiles, outfiles, otherargs, controls=aControls
     )
+
+
+def create_categories_sgl_band(
+    input_img: str,
+    output_img: str,
+    recode_lut: List[Tuple[int, Tuple[float, float]]],
+    img_band: int = 1,
+    gdalformat: str = "KEA",
+    datatype: int = rsgislib.TYPE_8UINT,
+    backgrd_val: int = 0,
+):
+    """
+    A function which categories a continuous image band based on a look up
+    table (LUT) provided. The LUT should be a list specifying the output
+    value and lower (>=) and upper (<) thresholds for that category.
+    For example, (1, (10, 20)). If you do not want to specify a lower or
+    upper value then use math.nan. For example, (2, (math.nan, 10))
+    or (3, (20, math.nan)).
+
+    :param input_img: The input image file path.
+    :param output_img: The output image where the distance has been recoded to
+                       categories using the recode_lut.
+    :param recode_lut: The recoding LUT specifying the categories to split the
+                       continuous band into.
+    :param img_band: The image band within the image (note. band indexes start at 1).
+                     Default = 1.
+    :param gdalformat: the output image file format (default: KEA)
+    :param datatype: the output image file data type (default: rsgislib.TYPE_8UINT)
+    :param backgrd_val: The background value used when recoding the distance image.
+                        i.e., if a pixel does not fall into any of the categories
+                        specified then it will be given this value.
+
+    """
+    recode_exp = ""
+    first = True
+    for lut_ent in recode_lut:
+        if math.isnan(lut_ent[1][0]):
+            ent_exp = f"(b{img_band} < {lut_ent[1][1]})?{lut_ent[0]}"
+        elif math.isnan(lut_ent[1][1]):
+            ent_exp = f"(b{img_band} >= {lut_ent[1][0]})?{lut_ent[0]}"
+        else:
+            ent_exp = (
+                f"(b{img_band} >= {lut_ent[1][0]})&&"
+                f"(b{img_band} < {lut_ent[1][1]})?{lut_ent[0]}"
+            )
+
+        if first:
+            recode_exp = ent_exp
+            first = False
+        else:
+            recode_exp = f"{recode_exp}:{ent_exp}"
+
+    recode_exp = f"{recode_exp}:{backgrd_val}"
+    image_math(input_img, output_img, recode_exp, gdalformat, datatype)
+
+
+def calc_img_correlation(
+    in_a_img: str,
+    in_b_img: str,
+    img_a_band: int,
+    img_b_band: int,
+    img_a_no_data: float = None,
+    img_b_no_data: float = None,
+    corr_stat_method: int = rsgislib.STATS_CORR_PEARSONS,
+) -> (float, float):
+    """
+    A function which calculates the correlation between two input image bands.
+
+    :param in_a_img: The path to input image A.
+    :param in_b_img: The path to input image B.
+    :param img_a_band: The band within input image A
+    :param img_b_band: The band within input image B
+    :param img_a_no_data: The no data value in image A.
+                          If None then read from image header.
+    :param img_b_no_data: The no data value in image B.
+                          If None then read from image header.
+    :param corr_stat_method: The correlation method rsgislib.STATS_CORR_.
+                             Default: rsgislib.STATS_CORR_PEARSONS
+    :return: correlation coefficient and p value
+    """
+    import rsgislib.tools.geometrytools
+    import rsgislib.imageutils
+    import scipy.stats
+
+    in_a_img_band_count = rsgislib.imageutils.get_img_band_count(in_a_img)
+    if (img_a_band < 1) or (img_a_band > in_a_img_band_count):
+        raise rsgislib.RSGISPyException(
+            f"The band specified ({img_a_band}) for image A is not within the image."
+        )
+    in_b_img_band_count = rsgislib.imageutils.get_img_band_count(in_b_img)
+    if (img_b_band < 1) or (img_b_band > in_b_img_band_count):
+        raise rsgislib.RSGISPyException(
+            f"The band specified ({img_b_band}) for image B is not within the image."
+        )
+
+    if img_a_no_data is None:
+        img_a_no_data = rsgislib.imageutils.get_img_no_data_value(in_a_img, img_a_band)
+    if img_a_no_data is None:
+        raise rsgislib.RSGISPyException(
+            "A no data value is not available for image A - please specify."
+        )
+
+    if img_b_no_data is None:
+        img_b_no_data = rsgislib.imageutils.get_img_no_data_value(in_b_img, img_b_band)
+    if img_b_no_data is None:
+        raise rsgislib.RSGISPyException(
+            "A no data value is not available for image B - please specify."
+        )
+
+    img_a_bbox = rsgislib.imageutils.get_img_bbox(in_a_img)
+    img_b_bbox = rsgislib.imageutils.get_img_bbox(in_b_img)
+    bbox_sub = rsgislib.tools.geometrytools.bbox_intersection(img_a_bbox, img_b_bbox)
+
+    img_a_arr = rsgislib.imageutils.get_img_band_pxl_data(
+        in_a_img, img_band=img_a_band, bbox_sub=bbox_sub
+    )
+    img_a_arr.flatten()
+    img_b_arr = rsgislib.imageutils.get_img_band_pxl_data(
+        in_b_img, img_band=img_b_band, bbox_sub=bbox_sub
+    )
+    img_b_arr.flatten()
+
+    finite_pxls = numpy.logical_and(
+        numpy.isfinite(img_a_arr), numpy.isfinite(img_b_arr)
+    )
+    valid_rng_pxls = numpy.logical_and(
+        img_a_arr != img_a_no_data, img_b_arr != img_b_no_data
+    )
+    vld_pxls = numpy.logical_and(valid_rng_pxls, finite_pxls)
+
+    img_a_arr = img_a_arr[vld_pxls]
+    img_b_arr = img_b_arr[vld_pxls]
+
+    if (len(img_a_arr) > 5) and (len(img_b_arr) > 5):
+        if corr_stat_method == rsgislib.STATS_CORR_PEARSONS:
+            imgs_corr_coeff, imgs_corr_p = scipy.stats.pearsonr(img_a_arr, img_b_arr)
+        elif corr_stat_method == rsgislib.STATS_CORR_SPEARMAN:
+            imgs_corr_coeff, imgs_corr_p = scipy.stats.spearmanr(img_a_arr, img_b_arr)
+        elif corr_stat_method == rsgislib.STATS_CORR_KENDALL_TAU:
+            imgs_corr_coeff, imgs_corr_p = scipy.stats.kendalltau(img_a_arr, img_b_arr)
+        elif corr_stat_method == rsgislib.STATS_CORR_POINT_BISERIAL:
+            imgs_corr_coeff, imgs_corr_p = scipy.stats.pointbiserialr(
+                img_a_arr, img_b_arr
+            )
+        else:
+            raise rsgislib.RSGISPyException(
+                "Do not recognise the correlation method specified"
+            )
+        imgs_corr_coeff = float(imgs_corr_coeff)
+        imgs_corr_p = float(imgs_corr_p)
+    else:
+        imgs_corr_coeff = None
+        imgs_corr_p = None
+
+    return imgs_corr_coeff, imgs_corr_p
