@@ -722,7 +722,11 @@ def test_stretch_img(tmp_path):
 
     assert os.path.exists(output_img)
 
-"""
+
+@pytest.mark.skipif(
+    True,
+    reason="Sometimes stretch_img_with_stats freezes on MacOS and haven't figured out why yet...",
+)
 def test_stretch_img_with_stats(tmp_path):
     import rsgislib
     import rsgislib.imageutils
@@ -742,7 +746,7 @@ def test_stretch_img_with_stats(tmp_path):
     )
 
     assert os.path.exists(output_img)
-"""
+
 
 def test_normalise_img_pxl_vals(tmp_path):
     import rsgislib
